const express = require('express');
const bodyParser = require('body-parser');
const app = express();

// Use body-parser middleware
app.use(bodyParser.urlencoded({ extended: true }));

// Set EJS as the templating engine
app.set('view engine', 'ejs');

// Serve static files from the 'public' directory
app.use(express.static('public'));

// In-memory store for blog posts
let blogPosts = [];

// Routes will be defined in the next steps

// Start the server
app.listen(3000, () => {
  console.log('Server started on http://localhost:3000');
});
app.get('/', (req, res) => {
   res.render('index', { posts: blogPosts });
});
app.get('/posts/:id', (req, res) => {
   const postId = req.params.id;
   const post = blogPosts.find(p => p.id === postId);
   if (post) {
       res.render('post', { post });
   } else {
       res.status(404).send('Post not found');
   }
});
app.get('/create', (req, res) => {
   res.render('create');
});
app.post('/posts', (req, res) => {
   const { title, content } = req.body;
   const newPost = {
       id: Date.now().toString(),  // Simple ID based on timestamp
       title,
       content
   };
   blogPosts.push(newPost);
   res.redirect('/');
});
app.use((req, res) => {
    res.status(404).render('404');
});